from unittest import TestSuite, makeSuite
from Products.CMFMailIn import MailIn_Tool
from base import Base

class TestMailIn(Base):

    def test_simpleMailParsing(self):
        self.Tool.edit_configuration('return_mail')
        f = open('TestMail1.txt','r')

        x = self.Tool.postMailMessage(f.read())
        
        data = {'attachments': {},
                'body': 'THis is a mailIn test from ME.\n\nHa Ha\n\n-Andy\n\n',
                'headers': {'content-transfer-encoding': '7bit',
                            'content-type': 'text/plain;\n charset="iso-8859-1"',
                            'date': 'Tue, 13 Jun 2000 09:34:08 +0100',
                            'from': '"Andy Dawkins" <andyd@nipltd.com>',
                            'importance': 'Normal',
                            'message-id': '<NEBBLGACMKDPCFFIIEALKEDDCBAA.andyd@nipltd.com>',
                            'mime-version': '1.0',
                            'subject': 'Mail In Test',
                            'to': '<testing@legolas.private.nipltd.com>'},
                'localpart': 'testing'}
        
        self._assertDictsMatch(x, data)

    def test_simpleMailMessageCreation(self):
        memberFolder = self.Site.Members

        if not 'testing' in memberFolder.objectIds():
            memberFolder.invokeFactory(type_name='Folder', id="testing")
            
        f = open('TestMail1.txt','r')

        x = self.Tool.postMailMessage(f.read())

        assert x is None
        assert 'NEBBLGACMKDPCFFIIEALKEDDCBAAandydnipltdcom' in memberFolder.testing.objectIds()

    def test_mailMessageCreationWithFileAttachment(self):
        memberFolder = self.Site.Members

        if not 'testing' in memberFolder.objectIds():
            memberFolder.invokeFactory(type_name='Folder', id="testing")
            
        f = open('MailWithAttachment.txt','r')

        x = self.Tool.postMailMessage(f.read())

        assert '3CECBD2EAC3E9310nipltdcom' in memberFolder.testing.objectIds()
        message = memberFolder.testing['3CECBD2EAC3E9310nipltdcom']
        assert 'zope.jpeg' in message.Attachments()
        assert 'email.gif' in message.Attachments()
        assert x is None

    def _assertDictsMatch(self, dict1, dict2):
        """ checks two standard Python dictionaries, key by key, and
            identifies any that don't match
        """
        # perform simple equality check first
        if dict1 == dict2:
            return

        # now there must be something wrong...
        assert dict1.keys() == dict2.keys(), "dictionaries have different keys"

        for key in dict1.keys():
            assert dict1[key] == dict2[key], "key '%s' does not match" % key
        
def test_suite():
    return TestSuite((
        makeSuite( TestMailIn ),
        ))

if __name__ == '__main__':
    main(defaultTest='test_suite')
